@@ -104,6 +104,7 @@ oil_cpu_i386_getflags_cpuinfo (char *cpuinfo)
     if (strcmp (*f, "sse2") == 0) {
       OIL_DEBUG ("cpu flag %s", *f);
       oil_cpu_flags |= OIL_IMPL_FLAG_SSE2;
+      oil_cpu_flags |= OIL_IMPL_FLAG_MMXEXT;
     }
     if (strcmp (*f, "3dnow") == 0) {
       OIL_DEBUG ("cpu flag %s", *f);
@@ -180,6 +181,7 @@ oil_cpu_i386_getflags_cpuid (void)
   }
   if (edx & (1<<26)) {
     oil_cpu_flags |= OIL_IMPL_FLAG_SSE2;
+    oil_cpu_flags |= OIL_IMPL_FLAG_MMXEXT;
   }
   if (ecx & (1<<0)) {
     oil_cpu_flags |= OIL_IMPL_FLAG_SSE3;
@@ -396,3 +398,37 @@ oil_cpu_fault_check_disable (void)
   }
 }
 
+#if 0
+void oil_memory_prefetch_local (void *ptr, int n_bytes)
+{
+#ifdef __i386__
+  if (oil_cpu_flags & OIL_IMPL_FLAG_MMX) {
+    asm volatile (
+        "prefetcht0 %0\n"
+        :: "m" (ptr));
+  }
+#endif
+
+}
+
+void oil_memory_prefetch_transient (void *ptr, int n_bytes)
+{
+#ifdef __i386__
+  if (oil_cpu_flags & OIL_IMPL_FLAG_MMX) {
+    asm volatile (
+        "prefetchnta %0\n"
+        :: "m" (ptr));
+  }
+#endif
+
+}
+#endif
+
+#if 0
+double
+oil_cpu_get_ticks_per_second (void)
+{
+  return _oil_ticks_per_second;
+}
+#endif
+
