@@ -34,6 +34,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 
 extern OilFunctionClass *_oil_function_class_array[];
 extern OilFunctionImpl *_oil_function_impl_array[];
@@ -78,6 +79,33 @@ oil_init (void)
   OIL_INFO ("initialization completed in %ld usec", stop-start);
 }
 
+/**
+ * oil_init_no_optimize:
+ *
+ * Identical to @oil_init(), except that the profiling stage is not
+ * done.  This function is mainly useful for internal programs.
+ */
+void
+oil_init_no_optimize (void)
+{
+  static int inited = 0;
+  unsigned long start, stop;
+
+  if (inited) return;
+  inited = 1;
+
+  start = oil_profile_stamp_gtod ();
+
+  _oil_debug_init ();
+  _oil_cpu_init ();
+  oil_init_pointers ();
+  oil_init_structs ();
+
+  stop = oil_profile_stamp_gtod ();
+
+  OIL_INFO ("initialization completed in %ld usec", stop-start);
+}
+
 /**
  * oil_optimize_all:
  *
@@ -289,6 +317,8 @@ oil_class_optimize (OilFunctionClass * klass)
         klass->name);
     return;
   }
+
+  OIL_DEBUG("chose implementation %s", min_impl->name);
   klass->chosen_impl = min_impl;
   klass->func = min_impl->func;
 
