@@ -39,6 +39,7 @@
 #include <stdio.h>
 #include <math.h>
 
+static void oil_test_init_params (OilTest *test);
 static void fill_array (void *ptr, OilType type, int pre_n, int stride,
     int post_n);
 static double check_array (void *data, void *ref, OilType type, int pre_n,
@@ -121,6 +122,24 @@ oil_test_set_iterations (OilTest *test, int iterations)
   test->iterations = iterations;
 }
 
+void
+oil_test_init (OilTest *test)
+{
+  if (test->inited) {
+    return;
+  }
+
+  oil_test_init_params(test);
+
+  test->params[OIL_ARG_N].value = test->n;
+  
+  test->inited = 1;
+
+  if (test->klass->test_func) {
+    test->klass->test_func (test);
+  }
+}
+
 static void
 oil_test_check_function (void * priv)
 {
@@ -130,17 +149,7 @@ oil_test_check_function (void * priv)
   unsigned long args[10];
   unsigned int pointer_mask;
 
-  if (!test->inited) {
-    oil_test_init_params(test);
-
-    test->params[OIL_ARG_N].value = test->n;
-    
-    test->inited = 1;
-
-    if (test->klass->test_func) {
-      test->klass->test_func (test);
-    }
-  }
+  oil_test_init (test);
 
   OIL_LOG("calling function %s", test->impl->name);
 
@@ -172,6 +181,16 @@ oil_test_check_function (void * priv)
 
   oil_profile_init (&test->prof);
   for(i=0;i<test->iterations;i++){
+    int k;
+
+    for(k=0;k<test->proto->n_params;k++){
+      OilParameter *p;
+      j = test->proto->params[k].parameter_type;
+      p = &test->params[j];
+      if (p->direction == 'i') {
+        memcpy (p->test_data, p->src_data, p->size);
+      }
+    }
     _oil_test_marshal_function (test->impl->func, args, test->proto->n_params,
         pointer_mask, &test->prof);
   }
@@ -394,7 +413,7 @@ init_parameter (OilTest *test, OilParameter *p, OilParameter *ps)
   }
 }
 
-void
+static void
 oil_test_init_params (OilTest *test)
 {
   init_parameter (test, &test->params[OIL_ARG_DEST1],
@@ -453,6 +472,12 @@ fill_array (void *data, OilType type, int pre_n, int stride, int post_n)
     case OIL_TYPE_u32p:
       FILL(uint32_t,oil_rand_u32());
       break;
+    case OIL_TYPE_s64p:
+      FILL(int64_t,oil_rand_s64());
+      break;
+    case OIL_TYPE_u64p:
+      FILL(uint64_t,oil_rand_u64());
+      break;
     case OIL_TYPE_f32p:
       FILL(float,oil_rand_f32_0_1());
       break;
@@ -502,6 +527,12 @@ check_array (void *data, void *ref, OilType type, int pre_n, int stride, int pos
     case OIL_TYPE_u32p:
       CHECK(uint32_t);
       break;
+    case OIL_TYPE_s64p:
+      CHECK(int64_t);
+      break;
+    case OIL_TYPE_u64p:
+      CHECK(uint64_t);
+      break;
     case OIL_TYPE_f32p:
       CHECK(float);
       break;
